@@ -1,12 +1,15 @@
 #' Download, read and format STATS19 data in one function.
 #'
 #' @section Details:
-#' This function utilizes `dl_stats19` and `read_*` functions and returns a
-#' tibble (default), a data.frame, a sf object or a ppp object (according to the
-#' `output_format` parameter).
-#' The file downloaded would be for a specific year (e.g. 2017) or multiple
-#' years (e.g. c(2017, 2018)).
-#' See examples.
+#' This function uses gets STATS19 data. Behind the scenes it uses
+#' `dl_stats19()` and `read_*` functions, returning a
+#' `tibble` (default), `data.frame`, `sf` or `ppp` object, depending on the
+#' `output_format` parameter.
+#' The function returns data for a specific year (e.g. `year = 2017`) or multiple
+#' years (e.g. `year = c(2017, 2018)`).
+#' Note: for years before 2009 the function may return data from more years than are
+#' requested due to the nature of the files hosted at
+#' [data.gov.uk](https://data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-safety-data).
 #'
 #' As this function uses `dl_stats19` function, it can download many MB of data,
 #' so ensure you have a sufficient disk space.
@@ -25,8 +28,9 @@
 #' @param output_format A string that specifies the desired output format. The
 #'   default value is `"tibble"`. Other possible values are `"data.frame"`, `"sf"`
 #'   and `"ppp"`, that, respectively, returns objects of class [`data.frame`],
-#'   [`sf::sf`] and [`spatstat::ppp`]. Any other string is ignored and a tibble
+#'   [`sf::sf`] and [`spatstat.geom::ppp`]. Any other string is ignored and a tibble
 #'   output is returned. See details and examples.
+#' @param year Valid vector of one or more years from 1979 up until last year.
 #' @param ... Other arguments that should be passed to [format_sf()] or
 #'   [format_ppp()] functions. Read and run the examples.
 #'
@@ -55,10 +59,9 @@
 #' # multiple years
 #' get_stats19(c(2017, 2018), silent = TRUE, output_format = "sf")
 #'
-#' if (requireNamespace("spatstat", quietly = TRUE)) {
+#' if (requireNamespace("spatstat.core", quietly = TRUE)) {
 #' # ppp output
 #' x_ppp = get_stats19(2017, silent = TRUE, output_format = "ppp")
-#' spatstat::plot.ppp(x_ppp, use.marks = FALSE)
 #'
 #' # Multiple years
 #' get_stats19(c(2017, 2018), silent = TRUE, output_format = "ppp")
@@ -67,13 +70,13 @@
 #' # events occurred in a specific area. For example we can create a new bbox
 #' # of 5km around the city center of Leeds
 #'
-#' leeds_window = spatstat::owin(
+#' leeds_window = spatstat.geom::owin(
 #' xrange = c(425046.1, 435046.1),
 #' yrange = c(428577.2, 438577.2)
 #' )
 #'
 #' leeds_ppp = get_stats19(2017, silent = TRUE, output_format = "ppp", window = leeds_window)
-#' spatstat::plot.ppp(leeds_ppp, use.marks = FALSE, clipwin = leeds_window)
+#' spatstat.geom::plot.ppp(leeds_ppp, use.marks = FALSE, clipwin = leeds_window)
 #'
 #' # or even more fancy examples where we subset all the events occurred in a
 #' # pre-defined polygon area
@@ -87,10 +90,10 @@
 #' # greater_london_sf_polygon = sf::st_transform(greater_london_sf_polygon, 27700)
 #' # then we extract the coordinates and create the window object.
 #' # greater_london_polygon = sf::st_coordinates(greater_london_sf_polygon)[, c(1, 2)]
-#' # greater_london_window = spatstat::owin(poly = greater_london_polygon)
+#' # greater_london_window = spatstat.geom::owin(poly = greater_london_polygon)
 #'
 #' # greater_london_ppp = get_stats19(2017, output_format = "ppp", window = greater_london_window)
-#' # spatstat::plot.ppp(greater_london_ppp, use.marks = FALSE, clipwin = greater_london_window)
+#' # spatstat.geom::plot.ppp(greater_london_ppp, use.marks = FALSE, clipwin = greater_london_window)
 #' }
 #' }
 get_stats19 = function(year = NULL,
@@ -126,6 +129,10 @@ get_stats19 = function(year = NULL,
     output_format = "tibble"
   }
 
+  if(!is.null (year)) {
+    year = check_year(year)
+  }
+
   if(is.vector(year) && length(year) > 1) {
     all  = list()
     i = 1
@@ -144,7 +151,7 @@ get_stats19 = function(year = NULL,
       i = i + 1
     }
     if (output_format == "ppp") {
-      all = do.call(spatstat::superimpose, all)
+      all = do.call(spatstat.geom::superimpose, all)
     } else {
       all_colnames = unique(unlist(lapply(all, names)))
       all = lapply(all, function(x) {
@@ -196,6 +203,3 @@ get_stats19 = function(year = NULL,
   read_in
 }
 
-
-
-
